@@ -6,11 +6,13 @@ from .trainer import Trainer
 from .yolov5_wrapper import clone_yolo
 
 AUTH = Auth()
+CONNECTED = False
 
 
 def train_model() -> None:
     """Starts training from next in queue"""
     clone_yolo()
+    connect_to_hub()
     trainer = Trainer(None, AUTH)  # No model so next in train queue is fetched
     if trainer.model is not None:
         trainer.start()
@@ -18,16 +20,14 @@ def train_model() -> None:
 
 def connect_to_hub(password=False) -> bool:
     """Authenticates user with Ultralytics HUB"""
-
-    if password:
-        success = AUTH.attempt_signin()
-    else:
-        success = AUTH.attempt_api_key()
-
-    return success
+    global CONNECTED
+    if not CONNECTED:
+        CONNECTED = AUTH.attempt_signin() if password else AUTH.attempt_api_key()
+    return CONNECTED
 
 
 def main():
+    # Deprecated
     clone_yolo()
     if BY_PASS_LOGIN:
         AUTH.sign_in_with_email_and_password("kalen.michael@ultralytics.com", "7654321")
