@@ -36,27 +36,24 @@ class Trainer:
             res = r.json()
 
             if res["data"] is None:
-                print(f"\n{PREFIX}ERROR: Unable to fetch model")
+                print(f"{PREFIX}ERROR: Unable to fetch model")
                 return None  # Cannot train without model
             elif not res["data"]:
-                print(f"\n{PREFIX}You have no models pending training.")
+                print(f"{PREFIX}No models pending training.")
                 return None  # Cannot train without model
             else:
-                self.model_id = res["data"][
-                    "id"]  # Append id as it may be fetched from queue and unknown
+                self.model_id = res["data"]["id"]  # Append id as it may be fetched from queue and unknown
                 return res["data"]
         except requests.exceptions.ConnectionError:
-            print(f'\n{PREFIX}ERROR: The HUB server is not online. Please try again later.')
+            print(f'{PREFIX}ERROR: The HUB server is not online. Please try again later.')
             return None
             # sys.exit(141)  # TODO: keep this 141 sys exit error code?
 
     def _connect_callbacks(self):
         callback_handler = YOLOv5.new_callback_handler()
         hub_logger = HUBLogger(self.model_id, self.auth)
-        callback_handler.register_action("on_model_save", "HUB",
-                                         hub_logger.on_model_save)
-        callback_handler.register_action("on_train_end", "HUB",
-                                         hub_logger.on_train_end)
+        callback_handler.register_action("on_model_save", "HUB", hub_logger.on_model_save)
+        callback_handler.register_action("on_train_end", "HUB", hub_logger.on_train_end)
         self.callbacks = callback_handler
 
     def start(self):
